@@ -7,7 +7,7 @@ import glob
 import json
 
 def find_files(directory, prefix="", postfix="", recursive=True, onlyfiles=True,
-          fullpath=False, olderthan=None):
+          fullpath=False, olderthan=None, inorder=False):
     """Find files in a directory.
 
     Parameters
@@ -26,6 +26,8 @@ def find_files(directory, prefix="", postfix="", recursive=True, onlyfiles=True,
         Give full path. Defaults to False. If recursive=True, fullpath is given automatically.
     olderthan : int (optional)
         Match only files older than X seconds from now. Defaults to None
+    inorder : Boolean (optional)
+        Return sorted list of filenames. Defaults to False
 
     Returns
     -------
@@ -72,6 +74,9 @@ def find_files(directory, prefix="", postfix="", recursive=True, onlyfiles=True,
                     tfiles.append(f)
         files = tfiles
 
+    if inorder:
+        files = list(sorted(files))
+
     return files
 
 
@@ -90,3 +95,39 @@ def clean(files):
         except OSError:
             pass
     return
+
+
+def does_file_exist(f):
+    """
+    Check if file exist
+
+    Parameters
+    ----------
+    f : str
+        name of file to check
+
+    Returns
+    -------
+    state : boolean
+        Whether the file exist (True) or not exist (False)
+    """
+    state = os.path.isfile(f)
+    return state
+
+
+def does_dir_exist(f):
+    """
+    Check if directory exist
+
+    Parameters
+    ----------
+    f : str
+        name of directory to check
+
+    Returns
+    -------
+    state : boolean
+        Whether the directory exist (True) or not exist (False)
+    """
+    state = os.path.exists(f)
+    return state
\ No newline at end of file
